import { BrowserHistory, HashHistory, MemoryHistory } from 'history';
import { ContextOptions } from '../../../providers/context';
export interface User {
    accessToken: string;
    refreshToken: string;
    expiresIn: number;
    expires: string;
    mfaRequired: boolean;
    id: string;
    email: string;
    mfaEnabled: boolean;
    name: string;
    phone?: string;
    profileImage: string;
    [key: string]: any;
}
export declare enum LoginStep {
    'preLogin' = "preLogin",
    'loginWithPassword' = "loginWithPassword",
    'loginWithTwoFactor' = "loginWithTwoFactor",
    'redirectToSSO' = "redirectToSSO",
    'success' = "success"
}
export interface LoginState {
    loading: boolean;
    error?: any;
    step: LoginStep;
    ssoRedirectUrl?: string;
    mfaRequired?: boolean;
    mfaToken?: string;
}
export declare enum ActivateStep {
    'activating' = "activating",
    'success' = "success"
}
export interface ActivateState {
    loading: boolean;
    error?: any;
    step: ActivateStep;
}
export declare enum ForgotPasswordStep {
    'forgotPassword' = "forgotPassword",
    'success' = "success"
}
export interface ForgotPasswordState {
    step: ForgotPasswordStep;
    email: string;
    loading: boolean;
    error?: any;
}
export declare enum MFAStep {
    'verify' = "verify",
    'recoveryCode' = "recoveryCode",
    'disable' = "disable"
}
export interface MFAState {
    step: MFAStep;
    loading: boolean;
    error?: any;
    recoveryCode: string;
    qrCode: string | null;
}
export interface AuthUrlProps {
    authenticatedUrl: string;
    loginUrl: string;
    logoutUrl: string;
    activateUrl: string;
    forgetPasswordUrl: string;
    resetPasswordUrl: string;
}
export interface AuthProviderProps {
    context: ContextOptions;
    routes: AuthUrlProps;
    history: BrowserHistory | HashHistory | MemoryHistory;
}
export interface AuthState {
    error?: any;
    isAuthenticated: boolean;
    isLoading: boolean;
    user?: User;
    isSSOAuth: boolean;
    loginState: LoginState;
    activateState: ActivateState;
    forgetPasswordState: ForgotPasswordState;
    mfaState: MFAState;
}
export declare type PreLoginPayload = {
    email: string;
};
export declare type LoginPayload = {
    email: string;
    password: string;
};
export declare type LogoutPayload = () => void;
export declare type LoginWithMfaPayload = {
    mfaToken: string;
    value: string;
};
export declare type ActivateAccountPayload = {
    token: string;
    userId: string;
    password: string;
};
export declare type ForgotPasswordPayload = PreLoginPayload;
export declare type ResetPasswordPayload = ActivateAccountPayload;
export declare type VerifyMfaPayload = {
    mfaToken: string;
};
export declare type DisableMfaPayload = VerifyMfaPayload;
//# sourceMappingURL=interfaces.d.ts.map