const path = require('path');
const MiniCssExtractPlugin = require('mini-css-extract-plugin');
const nodeExternals = require('webpack-node-externals');
const OptimizeCssAssetsPlugin = require('optimize-css-assets-webpack-plugin');
const TerserJSPlugin = require('terser-webpack-plugin');
const ReplacePlugin = require('webpack-plugin-replace');
// npm install --no-save webpack-bundle-analyzer
// const BundleAnalyzerPlugin = require('webpack-bundle-analyzer').BundleAnalyzerPlugin;

const removeEmpty = e => !!e;

const { version } = require('./package.json');

module.exports = (env, argv) => {

  console.log('BRANCH_NAME - ', process.env.BRANCH_NAME);

  const isProduction = argv.mode === 'production';
  const devBuild = process.env.BRANCH_NAME === 'develop' ? '-dev' : '';

  const minCssLoader = {
    loader: MiniCssExtractPlugin.loader,
    options: {
      esModule: false,
    },
  };

  const cssLoader = {
    loader: 'css-loader',
    options: {
      sourceMap: !isProduction,
    },
  };

  const config = {
    entry: './src/index.tsx',
    output: {
      path: path.resolve(__dirname, 'dist'),
      filename: 'main.js',
      libraryTarget: 'commonjs2', // THIS IS THE MOST IMPORTANT LINE! :mindblow: I wasted more than 2 days until realize this was th
    },
    devtool: !isProduction && 'source-map',
    resolve: {
      extensions: ['.js', '.jsx', '.json', '.ts', '.tsx'],
    },
    module: {
      rules: [
        {
          test: /\.(ts|tsx)$/,
          loader: 'ts-loader',
        },
        {
          enforce: 'pre',
          test: /\.js$/,
          loader: 'source-map-loader',
        },
        {
          test: /\.(png|jpe?g|gif|svg)$/,
          use: [
            {
              loader: 'url-loader',
              options: {
                name: '[path][name].[ext]',
              },
            },
            {
              loader: 'file-loader',
            },
          ],
        },
        {
          test: /\.css$/i,
          use: [!isProduction && 'style-loader', isProduction && minCssLoader, cssLoader].filter(removeEmpty),
        },
        {
          test: /\.scss$/,
          use: [
            !isProduction && 'style-loader',
            isProduction && minCssLoader,
            cssLoader,
            {
              loader: 'sass-loader',
              options: {
                sourceMap: !isProduction,
              },
            },
          ].filter(removeEmpty),
        },
      ],
    },
    externals: [
      nodeExternals({
        whitelist: [],
      }),
    ],
    plugins: [
      isProduction && new MiniCssExtractPlugin({ filename: 'styles.min.css' }),
      isProduction &&
      new ReplacePlugin({
        paterns: ['// extracted by mini-css-extract-plugin'],
        values: {
          '// extracted by mini-css-extract-plugin': `
var cssId = 'fronteggCss';
if (document && !document.getElementById(cssId)) {
    var h  = document.getElementsByTagName('head')[0];
    var l  = document.createElement('link');
    l.id  = cssId;
    l.rel  = 'stylesheet';
    l.type = 'text/css';
    l.href = 'https://cdn.jsdelivr.net/npm/@frontegg/react${devBuild}@${version}/dist/styles.min.css';
    l.media = 'all';
    h.appendChild(l);
}`,
        },
      }),
      // new BundleAnalyzerPlugin(),
    ].filter(removeEmpty),
  };

  if (isProduction) {
    config.optimization = {
      minimizer: [new TerserJSPlugin({}), new OptimizeCssAssetsPlugin({})],
    };
  }

  return config;
};
