import ts from "rollup-plugin-typescript2";
import image from "@rollup/plugin-image";
import commonjs from "@rollup/plugin-commonjs";
import replace from "@rollup/plugin-replace";
import progress from "rollup-plugin-progress";
import postcss from "rollup-plugin-postcss";
import cssnano from "cssnano";
import resolve from "@rollup/plugin-node-resolve";
import typescript from "typescript";
import postcssSvg from "postcss-svg";
import { terser } from "rollup-plugin-terser";
import json from "@rollup/plugin-json";
import fs from "fs";
import path from "path";

const pkg = JSON.parse(fs.readFileSync(path.join(process.cwd(), "./package.json")));
const isProduction = process.env.NODE_ENV === "production";

export default {
  input: "src/index.tsx",
  output: {
    dir: "dist/",
    format: "cjs",
    compact: isProduction,
    sourcemap: !isProduction
  },
  inlineDynamicImports: true,
  cache: !isProduction,
  external: [
    'react-is',
    'prop-types',
    '@stardust-ui/*',
    ...Object.keys(pkg.dependencies || [])
  ],
  plugins: [
    resolve({
      jsnext: true,
      browser: false,
      preferBuiltins: true,
      extensions: [".js", ".jsx", ".ts", ".tsx", ".json"]
    }),
    commonjs({
      sourceMap: false,
      // include: [/node_modules\/prop-types/],
      // namedExports: {
      //   'node_modules/prop-types/index.js':['oneOfType', 'func', 'element'],
      // },
    }),
    ts({
      tsconfig: "./tsconfig-build.json",
      typescript,
      clean: true,
      check: true,
    }),
    postcss({
      minimize: isProduction,
      sourceMap: !isProduction,
      plugins: [cssnano(), postcssSvg()]
    }),
    json(),
    image(),
    replace({
      patterns: [
        {
          transform(code, id) {
            if (/src\/index.tsx$/.test(id)) {
              return `require('./index.css');\n${code}`;
            }
            return code;
          }
        }
      ]
    }),
    isProduction && terser(),
    progress()
  ]
};
